# CloudFerry Development Lab
==========

## Overview

This allows for setting up a development lab environment using
[Vagrant](http://www.vagrantup.com/downloads.html).

## Lab Description

Vagrant sets up 4 nodes:
 - Openstack Grizzly all-in-one node on Ubuntu 12.04;
 - Openstack Icehouse all-in-one node on Ubuntu 14.04;
 - Openstack Juno all-in-one node on Ubuntu 14.04;
 - NFS server node on Ubuntu 14.04

## Configuration

Configuration is done through modifying `config.ini`. Most recent configurable
options:

 - `public_key_path` -- public key CloudFerry uses to ssh into SRC and DST
   migration environments;

## Prerequisites

 - Vagrant, version >= 1.6
 - Virtualbox

## Setup

 1. Make sure you have all prerequisites installed;
 2. Clone [CloudFerry](https://github.com/MirantisWorkloadMobility/CloudFerry)
    repository and navigate to `cloudferry_devlab` folder
    ```
    git clone https://github.com/MirantisWorkloadMobility/CloudFerry.git
    cd CloudFerry/cloudferry_devlab
    ```
 3. Configure according to your needs (see Configuration)
 4. Start vagrant
    ```
    vagrant up
    ```
    or
    ```
    vagrant up grizzly juno
    ```
 5. You also can start minimum development environment by running:
    ```
    vagrant up grizzly icehouse nfs
    ```

## Common Vagrant use-cases

 1. Check current VMs state (whether it's up, down and so on)
   - `vagrant status`
 2. SSH
   - `vagrant ssh <vm name>`
   - `<vm name>` is one of grizzly, icehouse, juno or nfs
 3. SSH configuration used for each VM:
   - `vagrant ssh-config <vm name>`
 4. If something went wrong and you cannot ssh with keypairs, all the VMs have
    following users:
   - Username: vagrant
   - Password: vagrant
 5. `vagrant` user is added to paswordless sudoers, so you can easily become
    root:
   - `sudo su -`

CloudFerry functional tests overview
==========

## Generate load in source cloud

Prepare virtual environment to run tests and scripts. You can use the same
venv as prepared for cloudferry with same requirements or using
`requirements.txt` installed. But also you'll need to install cloudferry_devlab
 as python package:
```bash
pip install -e cloudferry_devlab
```

Modify `config.py` if you'll need additional amount of OS objects described
below.
```bash
vim cloudferry_devlab/tests/config.py
```

Here's an example of small tenant:
- vms
- networks
- subnets
- users
- keypairs
- tenants
- modifies tenants quotas
- upload images and snapshot
- creates flavors
- creates volumes

Prepare the same virtualenv as for Cloudferry and run to create Openstack
objects on source cloud:
```bash
generate_load ${CONFIGURATION_INI}
```

## Run migration

Example of migration script to run:
```bash
# Filter files (filter_{tenant_name}.yaml) were generated by generate_load
# using this pattern described in config.py:
# filters_file_naming_template = 'filter_{tenant_name}.yaml'.
filters=(`ls ${CF_DIR} | grep filter_.*.yaml`)
for ((i=0;i<${#filters[@]};++i))
# This loop is for changing filtering files in configuration.ini and executing
# specific functional tests for each migrated tenant.
do
    for scenario in `ls  scenario/stages/*.yaml; ls scenario/migrate_vms.yaml`
    # This loop is for changing scenario in configuration.ini and running
    # migration process.
    do
        cloudferry migrate configuration.ini --debug \
            --filter-path ${CF_DIR}'/'${filters[$i]} --scenario ${scenario}
    done
    pushd ${TESTS_DIR}
    nosetests -d -v --ignore-files=test_verify_dst_functionality \
                --attr=migrated_tenant=$tenant \
                --with-xunit \
                --xunit-file=nosetests.xml \
                --tc-file ${CONFIGURATION_INI} \
                --tc=general.cloudferry_dir:${CF_DIR} \
                --tc=general.configuration_ini_path:${CONFIGURATION_INI} \
                --tc=general.filter_path:${filters[$i]}
    popd
    last_filter=${filters[$i]}
done
```

## Verify results

To execute tests run:
```bash
cd cloudferry_devlab/tests
nosetests -d -v --with-xunit \
                --xunit-file=nosetests.xml \
                --tc-file ${CONFIGURATION_INI} \
                --tc=general.cloudferry_dir:${CF_DIR} \
                --tc=general.configuration_ini_path:${CONFIGURATION_INI}
                --tc=general.filter_path:${last_filter}
```

## CloudFerry usage

Use CloudFerry [Quickstart guide](https://github.com/MirantisWorkloadMobility/CloudFerry/blob/master/QUICKSTART.md)
